# Published Opinions

Published Opinions of the appellate courts are opinions certified for publication or ordered published and may be cited or relied on by courts and parties.

- Official Reports Opinions (Searchable 1850-Present) are the searchable, citable, published opinions that reflect postfiling corrections. This no-fee service is provided by LexisNexis.

- Slip Opinions are as-filed versions of opinions. Slip opinions certified for publication do not reflect enhancement, editing and correction for the Official Reports.

Supreme Court slip opinions are posted immediately on filing at 10:00 a.m. on Mondays and Thursdays. Court of Appeal slip opinions are posted throughout the day as soon after filing as possible.

Use the list below to select the slip opinions certified for publication, or ordered published, that you want to view and click on the "view" button to activate your selection.

Date Posted | Docket #/ File Format | Description
--- | --- | ---
Jul 18 2013 | G047100 [PDF] [DOC] | Natalie D. v. State Dept. Health Care Services 7/18/13 CA4/3 Case Details
Jul 18 2013 | G046470 [PDF] [DOC] | Baughman v. Walt Disney World 7/18/13 CA4/3 Case Details
Jul 18 2013 | G046032A [PDF] [DOC] | P. v. Perez 2/4/13 CA4/3 Case Details
Jul 15 2013 | G047034 [PDF] [DOC] | Abers v. Rohrs 6/13/13 CA4/3 Case Details
Jul 11 2013 | G046263M [PDF] [DOC] | Marr. of Ficke 7/11/13 CA4/3 Case Details
Jul 10 2013 | G047013 [PDF] [DOC] | Orange Citizens v. Super. Ct. 7/10/13 CA4/3 Case Details
Jul 01 2013 | G046669 [PDF] [DOC] | SFPP v. Public Util. Com. 6/13/13 CA4/3 Case Details
Jul 01 2013 | G047244A [PDF] [DOC] | Havasu Lakeshore v. Fleming 5/28/13 CA4/3 Case Details
Jun 28 2013 | G047824 [PDF] [DOC] | Jointer v. Super. Ct. 6/28/13 CA4/3 Case Details
Jun 27 2013 | G046759 [PDF] [DOC] | Thompson v. Automobile Club etc. 6/7/13 CA4/3 Case Details
Jun 27 2013 | G047376 [PDF] [DOC] | Interstate Specialty v. ICRA Sapphire 6/27/13 CA4/3 Case Details
Jun 26 2013 | G045949 [PDF] [DOC] | Marr. of Greenway 6/3/13 CA4/3 Case Details
Jun 26 2013 | G046891 [PDF] [DOC] | Wittenburg v. Beachwalk Homeowners 6/26/13 CA4/3 Case Details
Jun 25 2013 | G047000 [PDF] [DOC] | Curry v. Super. Ct. 6/25/13 CA4/3 Case Details
Jun 19 2013 | G046899 [PDF] [DOC] | P. v. Rodriguez 6/13/13 CA4/3 Case Details
Jun 19 2013 | G046961 [PDF] [DOC] | In re R.V. 6/19/13 CA4/3 Case Details
Jun 19 2013 | G047244 [PDF] [DOC] | Havasu Lakeshore v. Fleming 5/28/13 CA4/3 Case Details
Jun 14 2013 | G047177 [PDF] [DOC] | Scott B. v. Bd. of Trustees Orange Co. High School 6/14/13 CA4/3 Case Details
Jun 13 2013 | G047134 [PDF] [DOC] | Teva Pharmaceuticals v. Super. Ct. 6/13/13 CA4/3 Case Details
Jun 12 2013 | G046121M [PDF] [DOC] | Jenkins v. JP Morgan 6/12/13 CA4/3 Case Details
Jun 12 2013 | G046129M [PDF] [DOC] | P. v. Eid 6/12/13 CA4/3 Case Details
Jun 12 2013 | G047167 [PDF] [DOC] | Asso. of Deputy Sheriffs v. Cty. of Orange 6/12/13 CA4/3 Case Details
Jun 12 2013 | G046263 [PDF] [DOC] | Marr. of Ficke 6/12/13 CA4/3 Case Details
May 22 2013 | G046129 [PDF] [DOC] | P. v. Eid 5/22/13 CA4/3 Case Details
May 17 2013 | G046121 [PDF] [DOC] | Jenkins v. JP Morgan Chase 5/17/13 CA4/3 Case Details
May 10 2013 | G041702 [PDF] [DOC] | Faulkinbury v. Boyd & Associates 5/10/13 CA4/3 Case Details
May 08 2013 | G043999N [PDF] [DOC] | Kurtin v. Elieff 5/8/13 CA4/3 Case Details
Apr 30 2013 | G046273 [PDF] [DOC] | Copenbarger v. Morris Cerullo World Evangelism 4/3/13 CA4/3 Case Details
Apr 16 2013 | G043999A [PDF] [DOC] | Kurtin v. Elieff 4/16/13 CA4/3 Case Details
Mar 28 2013 | G044963 [PDF] [DOC] | P. v. McDonald 3/28/13 CA4/3 Case Details
Mar 27 2013 | G046549M [PDF] [DOC] | Soco West v. Cal. Environmental Protection 3/27/13 CA4/3 Case Details
Mar 26 2013 | G047627M [PDF] [DOC] | Fabian L. v. Super. Ct. 3/26/13 CA4/3 Case Details